====
jrnr
====


.. image:: https://img.shields.io/pypi/v/jrnr.svg
        :target: https://pypi.python.org/pypi/jrnr

.. image:: https://img.shields.io/travis/ClimateImpactLab/jrnr.svg
        :target: https://travis-ci.org/ClimateImpactLab/jrnr

.. image:: https://readthedocs.org/projects/jrnr/badge/?version=latest
        :target: https://jrnr.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/ClimateImpactLab/jrnr/shield.svg
     :target: https://pyup.io/repos/github/ClimateImpactLab/jrnr/
     :alt: Updates


Job Runner for Climate Impact Lab Jobs


* Free software: MIT license
* Documentation: https://jrnr.readthedocs.io.

jrnr is a tool to help you create, manage, and monitor your highly parallelizable jobs. 


Features
--------

* Job set-up utility for running parallel jobs 
* Currently only supports running slurm jobs 

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

